FEniCS-Plotly
=============

|codecov|

|CircleCI|

|image|

|Documentation Status|

A package for plotting FEniCS objects using plotly

-  Free software: MIT license
-  Documentation: https://fenics-plotly.readthedocs.io.
-  Source code: https://github.com/finsberg/fenics-plotly

Features
--------

Plot almost all types of FEnICS objects using one interface

Credits
-------

This package was created with
`Cookiecutter <https://github.com/audreyr/cookiecutter>`__ and the
`finsberg/cookiecutter-pypackage <https://github.com/finsberg/cookiecutter-pypackage>`__
project template.

This package is also inspired by `bvpy <https://gitlab.com/oali/bvpy>`__

.. |codecov| image:: https://codecov.io/gh/finsberg/fenics-plotly/branch/master/graph/badge.svg?token=PG2JS1SPKJ
   :target: https://codecov.io/gh/finsberg/fenics-plotly
.. |CircleCI| image:: https://circleci.com/gh/finsberg/fenics-plotly.svg?style=shield
   :target: https://circleci.com/gh/finsberg/fenics-plotly
.. |image| image:: https://img.shields.io/pypi/v/fenics_plotly.svg
   :target: https://pypi.python.org/pypi/fenics_plotly
.. |Documentation Status| image:: https://readthedocs.org/projects/fenics_plotly/badge/?version=latest
   :target: https://fenics-plotly.readthedocs.io/en/latest/?badge=latest
